==> driveR_0.4.1.zip: driveR/NEWS.md <==
# driveR 0.4.1

## Minor changes and bug fixes
- fixed a CRAN error due to a package documentation issue (#7)

# driveR 0.4.0

## Major Changes
- Added GRCh38 support

# driveR 0.3.0

## Major Changes
- Updated the cancer-type-specific thresholds

## Minor changes and bug fixes
- Updated citation to the method's article where necessary

# driveR 0.2.1

## Major Changes

- Updated the MTL model after fixing the issue below
- Fixed issue in `MCR_table`. The coordinates were converted to hg19 (from hg18)

## Minor changes and bug fixes

- Made use of `caret::predict.train` explicit
- Removed 'Homo.sapiens' from Imports field (not used)

# driveR 0.2.0

## Major Changes

- Fixed an issue in `create_SCNA_score_df()` where the SCNA score was not calculated because the column name for "MCR_overlap_percent" was incorrectly assigned as "transcript_overlap_percent"
- Updated the MTL classification model `TCGA_MTL_fit` and `specific_thresholds` after fixing the issue above

## Minor changes and bug fixes

- Updated citation information, correcting author name
- Minor changes in utility functions
- Added the `na.string` argument to `create_noncoding_impact_score_df()`, `predict_coding_impact()` and `create_features_df()` as the string that was used to indicate when a score is not available during annotation with ANNOVAR (default = ".")
- Generalized `determine_hotspot_genes()` to able to use occurrence annotations from different versions of COSMIC 
- Updated all data

# driver 0.1.1

Initial release

==> driveR_0.5.0.zip: driveR/NEWS.md <==
# driveR 0.5.0
## Major Changes
- added support for gene-level SCNA data frames to be used as input for `create_features_df()` and added an example gene-level SCNA data frame `example_gene_scna_table`

## Minor changes and bug fixes
- Moved `org.Hs.eg.db`, `TxDb.Hsapiens.UCSC.hg19.knownGene` and `TxDb.Hsapiens.UCSC.hg38.knownGene` from "Imports" to "Suggests" per new CRAN policy. Relevant functions raise error if the required package is not installed.

# driveR 0.4.1

## Minor changes and bug fixes
- fixed a CRAN error due to a package documentation issue (#7)

# driveR 0.4.0

## Major Changes
- Added GRCh38 support

# driveR 0.3.0

## Major Changes
- Updated the cancer-type-specific thresholds

## Minor changes and bug fixes
- Updated citation to the method's article where necessary

# driveR 0.2.1

## Major Changes

- Updated the MTL model after fixing the issue below
- Fixed issue in `MCR_table`. The coordinates were converted to hg19 (from hg18)

## Minor changes and bug fixes

- Made use of `caret::predict.train` explicit
- Removed 'Homo.sapiens' from Imports field (not used)

# driveR 0.2.0

## Major Changes

- Fixed an issue in `create_SCNA_score_df()` where the SCNA score was not calculated because the column name for "MCR_overlap_percent" was incorrectly assigned as "transcript_overlap_percent"
- Updated the MTL classification model `TCGA_MTL_fit` and `specific_thresholds` after fixing the issue above

## Minor changes and bug fixes

- Updated citation information, correcting author name
- Minor changes in utility functions
- Added the `na.string` argument to `create_noncoding_impact_score_df()`, `predict_coding_impact()` and `create_features_df()` as the string that was used to indicate when a score is not available during annotation with ANNOVAR (default = ".")
- Generalized `determine_hotspot_genes()` to able to use occurrence annotations from different versions of COSMIC 
- Updated all data

# driver 0.1.1

Initial release
